# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: paperpilot_common/protobuf/paper/paper.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder

# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2

from paperpilot_common.protobuf.common import util_pb2 as paperpilot__common_dot_protobuf_dot_common_dot_util__pb2

DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(
    b'\n,paperpilot_common/protobuf/paper/paper.proto\x12\x05paper\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x1bgoogle/protobuf/empty.proto\x1a\x1egoogle/protobuf/wrappers.proto\x1a,paperpilot_common/protobuf/common/util.proto"\x15\n\x07PaperId\x12\n\n\x02id\x18\x01 \x01(\t"\xf5\x02\n\x0bPaperDetail\x12\n\n\x02id\x18\x01 \x01(\t\x12\x12\n\nproject_id\x18\x02 \x01(\t\x12\r\n\x05title\x18\x03 \x01(\t\x12\x10\n\x08\x61\x62stract\x18\x04 \x01(\t\x12\x10\n\x08keywords\x18\x05 \x03(\t\x12\x0f\n\x07\x61uthors\x18\x06 \x03(\t\x12\x0c\n\x04tags\x18\x07 \x03(\t\x12\x18\n\x10publication_year\x18\x08 \x01(\x05\x12\x13\n\x0bpublication\x18\t \x01(\t\x12\x0e\n\x06volume\x18\n \x01(\t\x12\r\n\x05issue\x18\x0b \x01(\t\x12\r\n\x05pages\x18\x0c \x01(\t\x12\x0b\n\x03url\x18\r \x01(\t\x12\x0b\n\x03\x64oi\x18\x0e \x01(\t\x12\x0c\n\x04\x66ile\x18\x0f \x01(\t\x12/\n\x0b\x63reate_time\x18\x10 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12/\n\x0bupdate_time\x18\x11 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\r\n\x05\x65vent\x18\x12 \x01(\t"Y\n\x10ListPaperRequest\x12\x12\n\nproject_id\x18\x01 \x01(\t\x12\x0c\n\x04page\x18\x02 \x01(\x05\x12\x11\n\tpage_size\x18\x03 \x01(\x05\x12\x10\n\x08order_by\x18\x04 \x01(\t"Y\n\x11ListPaperResponse\x12"\n\x06papers\x18\x01 \x03(\x0b\x32\x12.paper.PaperDetail\x12\r\n\x05total\x18\x02 \x01(\x05\x12\x11\n\tnext_page\x18\x03 \x01(\x05"K\n\x12\x43reatePaperRequest\x12\x12\n\nproject_id\x18\x01 \x01(\t\x12!\n\x05paper\x18\x02 \x01(\x0b\x32\x12.paper.PaperDetail"Q\n\x17UpdateAttachmentRequest\x12\x10\n\x08paper_id\x18\x01 \x01(\t\x12\x0c\n\x04\x66ile\x18\x02 \x01(\t\x12\x16\n\x0e\x66\x65tch_metadata\x18\x03 \x01(\x08"C\n\x17UploadAttachmentRequest\x12\x10\n\x08paper_id\x18\x01 \x01(\t\x12\x16\n\x0e\x66\x65tch_metadata\x18\x02 \x01(\x08"9\n\x18UploadAttachmentResponse\x12\x1d\n\x05token\x18\x01 \x01(\x0b\x32\x0e.util.OssToken"<\n\x18\x43reatePaperByLinkRequest\x12\x12\n\nproject_id\x18\x01 \x01(\t\x12\x0c\n\x04link\x18\x02 \x01(\t2\xc1\x01\n\x0cPaperService\x12\x32\n\x08\x41\x64\x64Paper\x12\x12.paper.PaperDetail\x1a\x12.paper.PaperDetail\x12\x35\n\x0bUpdatePaper\x12\x12.paper.PaperDetail\x1a\x12.paper.PaperDetail\x12\x46\n\x10UpdateAttachment\x12\x1e.paper.UpdateAttachmentRequest\x1a\x12.paper.PaperDetail2\xcf\x03\n\x12PaperPublicService\x12>\n\tListPaper\x12\x17.paper.ListPaperRequest\x1a\x18.paper.ListPaperResponse\x12.\n\x08GetPaper\x12\x0e.paper.PaperId\x1a\x12.paper.PaperDetail\x12<\n\x0b\x43reatePaper\x12\x19.paper.CreatePaperRequest\x1a\x12.paper.PaperDetail\x12H\n\x11\x43reatePaperByLink\x12\x1f.paper.CreatePaperByLinkRequest\x1a\x12.paper.PaperDetail\x12\x35\n\x0bUpdatePaper\x12\x12.paper.PaperDetail\x1a\x12.paper.PaperDetail\x12S\n\x10UploadAttachment\x12\x1e.paper.UploadAttachmentRequest\x1a\x1f.paper.UploadAttachmentResponse\x12\x35\n\x0b\x44\x65letePaper\x12\x0e.paper.PaperId\x1a\x16.google.protobuf.Emptyb\x06proto3'
)

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, "paperpilot_common.protobuf.paper.paper_pb2", _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
    DESCRIPTOR._options = None
    _globals["_PAPERID"]._serialized_start = 195
    _globals["_PAPERID"]._serialized_end = 216
    _globals["_PAPERDETAIL"]._serialized_start = 219
    _globals["_PAPERDETAIL"]._serialized_end = 592
    _globals["_LISTPAPERREQUEST"]._serialized_start = 594
    _globals["_LISTPAPERREQUEST"]._serialized_end = 683
    _globals["_LISTPAPERRESPONSE"]._serialized_start = 685
    _globals["_LISTPAPERRESPONSE"]._serialized_end = 774
    _globals["_CREATEPAPERREQUEST"]._serialized_start = 776
    _globals["_CREATEPAPERREQUEST"]._serialized_end = 851
    _globals["_UPDATEATTACHMENTREQUEST"]._serialized_start = 853
    _globals["_UPDATEATTACHMENTREQUEST"]._serialized_end = 934
    _globals["_UPLOADATTACHMENTREQUEST"]._serialized_start = 936
    _globals["_UPLOADATTACHMENTREQUEST"]._serialized_end = 1003
    _globals["_UPLOADATTACHMENTRESPONSE"]._serialized_start = 1005
    _globals["_UPLOADATTACHMENTRESPONSE"]._serialized_end = 1062
    _globals["_CREATEPAPERBYLINKREQUEST"]._serialized_start = 1064
    _globals["_CREATEPAPERBYLINKREQUEST"]._serialized_end = 1124
    _globals["_PAPERSERVICE"]._serialized_start = 1127
    _globals["_PAPERSERVICE"]._serialized_end = 1320
    _globals["_PAPERPUBLICSERVICE"]._serialized_start = 1323
    _globals["_PAPERPUBLICSERVICE"]._serialized_end = 1786
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: paperpilot_common/protobuf/user/auth.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder

# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2

from paperpilot_common.protobuf.user import user_pb2 as paperpilot__common_dot_protobuf_dot_user_dot_user__pb2

DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(
    b'\n*paperpilot_common/protobuf/user/auth.proto\x12\x04\x61uth\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x1bgoogle/protobuf/empty.proto\x1a*paperpilot_common/protobuf/user/user.proto"/\n\x0cLoginRequest\x12\r\n\x05phone\x18\x01 \x01(\t\x12\x10\n\x08password\x18\x02 \x01(\t"G\n\x05Token\x12\r\n\x05value\x18\x01 \x01(\t\x12/\n\x0b\x65xpire_time\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.Timestamp"h\n\rLoginResponse\x12\x1c\n\x04user\x18\x01 \x01(\x0b\x32\x0e.user.UserInfo\x12\x1b\n\x06\x61\x63\x63\x65ss\x18\x02 \x01(\x0b\x32\x0b.auth.Token\x12\x1c\n\x07refresh\x18\x03 \x01(\x0b\x32\x0b.auth.Token"&\n\x13RefreshTokenRequest\x12\x0f\n\x07refresh\x18\x01 \x01(\t"3\n\x14RefreshTokenResponse\x12\x1b\n\x06\x61\x63\x63\x65ss\x18\x01 \x01(\x0b\x32\x0b.auth.Token"#\n\x12SendSmsCodeRequest\x12\r\n\x05phone\x18\x01 \x01(\t""\n\x11\x43ountPhoneRequest\x12\r\n\x05phone\x18\x01 \x01(\t"\x1e\n\rCountResponse\x12\r\n\x05\x63ount\x18\x01 \x01(\x05"(\n\x14\x43ountUsernameRequest\x12\x10\n\x08username\x18\x01 \x01(\t2\xba\x03\n\x11\x41uthPublicService\x12\x30\n\x05Login\x12\x12.auth.LoginRequest\x1a\x13.auth.LoginResponse\x12@\n\x07Refresh\x12\x19.auth.RefreshTokenRequest\x1a\x1a.auth.RefreshTokenResponse\x12\x38\n\x06Logout\x12\x16.google.protobuf.Empty\x1a\x16.google.protobuf.Empty\x12\x38\n\x08Register\x12\x17.user.CreateUserRequest\x1a\x13.auth.LoginResponse\x12?\n\x0bSendSmsCode\x12\x18.auth.SendSmsCodeRequest\x1a\x16.google.protobuf.Empty\x12:\n\nCountPhone\x12\x17.auth.CountPhoneRequest\x1a\x13.auth.CountResponse\x12@\n\rCountUsername\x12\x1a.auth.CountUsernameRequest\x1a\x13.auth.CountResponseb\x06proto3'
)

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, "paperpilot_common.protobuf.user.auth_pb2", _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
    DESCRIPTOR._options = None
    _globals["_LOGINREQUEST"]._serialized_start = 158
    _globals["_LOGINREQUEST"]._serialized_end = 205
    _globals["_TOKEN"]._serialized_start = 207
    _globals["_TOKEN"]._serialized_end = 278
    _globals["_LOGINRESPONSE"]._serialized_start = 280
    _globals["_LOGINRESPONSE"]._serialized_end = 384
    _globals["_REFRESHTOKENREQUEST"]._serialized_start = 386
    _globals["_REFRESHTOKENREQUEST"]._serialized_end = 424
    _globals["_REFRESHTOKENRESPONSE"]._serialized_start = 426
    _globals["_REFRESHTOKENRESPONSE"]._serialized_end = 477
    _globals["_SENDSMSCODEREQUEST"]._serialized_start = 479
    _globals["_SENDSMSCODEREQUEST"]._serialized_end = 514
    _globals["_COUNTPHONEREQUEST"]._serialized_start = 516
    _globals["_COUNTPHONEREQUEST"]._serialized_end = 550
    _globals["_COUNTRESPONSE"]._serialized_start = 552
    _globals["_COUNTRESPONSE"]._serialized_end = 582
    _globals["_COUNTUSERNAMEREQUEST"]._serialized_start = 584
    _globals["_COUNTUSERNAMEREQUEST"]._serialized_end = 624
    _globals["_AUTHPUBLICSERVICE"]._serialized_start = 627
    _globals["_AUTHPUBLICSERVICE"]._serialized_end = 1069
# @@protoc_insertion_point(module_scope)



"""
Django Admin Logs - Models.
"""
import json

from django.contrib.admin.models import LogEntryManager


class NoUserEntryManager(LogEntryManager):
    """The No User LogEntry Model Manager."""

    def __init__(self, model=None):
        super().__init__()
        self.model = model

    def log_action(
        self,
        user_id,
        content_type_id,
        object_id,
        object_repr,
        action_flag,
        change_message="",
    ):
        if isinstance(change_message, list):
            change_message = json.dumps(change_message)
        return self.model.objects.create(
            user_id=0,
            content_type_id=content_type_id,
            object_id=str(object_id),
            object_repr=object_repr[:200],
            action_flag=action_flag,
            change_message=change_message,
        )

    def get_queryset(self):
        return super().get_queryset()



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import paperpilot_common.protobuf.user.user_pb2
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing_extensions.final
class ProjectId(google.protobuf.message.Message):
    """项目 ID"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ID_FIELD_NUMBER: builtins.int
    id: builtins.str
    def __init__(
        self,
        *,
        id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["id", b"id"]) -> None: ...

global___ProjectId = ProjectId

@typing_extensions.final
class ProjectInviteCode(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    INVITE_CODE_FIELD_NUMBER: builtins.int
    invite_code: builtins.str
    def __init__(
        self,
        *,
        invite_code: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["invite_code", b"invite_code"]) -> None: ...

global___ProjectInviteCode = ProjectInviteCode

@typing_extensions.final
class ProjectInfo(google.protobuf.message.Message):
    """项目简要信息"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ID_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    INVITE_CODE_FIELD_NUMBER: builtins.int
    OWNER_ID_FIELD_NUMBER: builtins.int
    MEMBERS_FIELD_NUMBER: builtins.int
    id: builtins.str
    """项目ID"""
    name: builtins.str
    """项目名称"""
    description: builtins.str
    """项目描述"""
    invite_code: builtins.str
    """邀请码"""
    owner_id: builtins.str
    """拥有者 ID"""
    @property
    def members(
        self,
    ) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[
        paperpilot_common.protobuf.user.user_pb2.UserInfo
    ]:
        """项目成员列表"""
    def __init__(
        self,
        *,
        id: builtins.str = ...,
        name: builtins.str = ...,
        description: builtins.str = ...,
        invite_code: builtins.str = ...,
        owner_id: builtins.str = ...,
        members: collections.abc.Iterable[paperpilot_common.protobuf.user.user_pb2.UserInfo] | None = ...,
    ) -> None: ...
    def ClearField(
        self,
        field_name: typing_extensions.Literal[
            "description",
            b"description",
            "id",
            b"id",
            "invite_code",
            b"invite_code",
            "members",
            b"members",
            "name",
            b"name",
            "owner_id",
            b"owner_id",
        ],
    ) -> None: ...

global___ProjectInfo = ProjectInfo

@typing_extensions.final
class ListProjectRequest(google.protobuf.message.Message):
    """获取项目列表请求"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PAGE_FIELD_NUMBER: builtins.int
    PAGE_SIZE_FIELD_NUMBER: builtins.int
    ORDER_BY_FIELD_NUMBER: builtins.int
    page: builtins.int
    """页码"""
    page_size: builtins.int
    """每页大小"""
    order_by: builtins.str
    """排序字段"""
    def __init__(
        self,
        *,
        page: builtins.int = ...,
        page_size: builtins.int = ...,
        order_by: builtins.str = ...,
    ) -> None: ...
    def ClearField(
        self, field_name: typing_extensions.Literal["order_by", b"order_by", "page", b"page", "page_size", b"page_size"]
    ) -> None: ...

global___ListProjectRequest = ListProjectRequest

@typing_extensions.final
class ListProjectResponse(google.protobuf.message.Message):
    """获取项目列表响应"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PROJECTS_FIELD_NUMBER: builtins.int
    TOTAL_FIELD_NUMBER: builtins.int
    NEXT_PAGE_FIELD_NUMBER: builtins.int
    @property
    def projects(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ProjectInfo]:
        """项目列表"""
    total: builtins.int
    """总数"""
    next_page: builtins.int
    """下一页"""
    def __init__(
        self,
        *,
        projects: collections.abc.Iterable[global___ProjectInfo] | None = ...,
        total: builtins.int = ...,
        next_page: builtins.int = ...,
    ) -> None: ...
    def ClearField(
        self,
        field_name: typing_extensions.Literal["next_page", b"next_page", "projects", b"projects", "total", b"total"],
    ) -> None: ...

global___ListProjectResponse = ListProjectResponse

@typing_extensions.final
class CreateProjectRequest(google.protobuf.message.Message):
    """创建项目请求"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NAME_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    name: builtins.str
    """项目名称"""
    description: builtins.str
    """项目描述"""
    def __init__(
        self,
        *,
        name: builtins.str = ...,
        description: builtins.str = ...,
    ) -> None: ...
    def ClearField(
        self, field_name: typing_extensions.Literal["description", b"description", "name", b"name"]
    ) -> None: ...

global___CreateProjectRequest = CreateProjectRequest

@typing_extensions.final
class UpdateProjectRequest(google.protobuf.message.Message):
    """修改项目请求"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ID_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    id: builtins.str
    """项目 ID"""
    name: builtins.str
    """项目名称"""
    description: builtins.str
    """项目描述"""
    def __init__(
        self,
        *,
        id: builtins.str = ...,
        name: builtins.str = ...,
        description: builtins.str = ...,
    ) -> None: ...
    def ClearField(
        self, field_name: typing_extensions.Literal["description", b"description", "id", b"id", "name", b"name"]
    ) -> None: ...

global___UpdateProjectRequest = UpdateProjectRequest

@typing_extensions.final
class CheckUserJoinedProjectRequest(google.protobuf.message.Message):
    """检查用户是否加入项目请求"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PROJECT_ID_FIELD_NUMBER: builtins.int
    USER_ID_FIELD_NUMBER: builtins.int
    project_id: builtins.str
    """项目 ID"""
    user_id: builtins.str
    """用户 ID"""
    def __init__(
        self,
        *,
        project_id: builtins.str = ...,
        user_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(
        self, field_name: typing_extensions.Literal["project_id", b"project_id", "user_id", b"user_id"]
    ) -> None: ...

global___CheckUserJoinedProjectRequest = CheckUserJoinedProjectRequest



from typing import Any, Callable

import grpc

from paperpilot_common.middleware.server.base import AsyncServerMiddleware, parse_method_name
from paperpilot_common.utils.db import close_old_connections
from paperpilot_common.utils.log import get_logger


class DBMiddleware(AsyncServerMiddleware):
    logger = get_logger("server.interceptor.db")

    async def intercept(
        self,
        method: Callable,
        request_or_iterator: Any,
        context: grpc.ServicerContext,
        method_name: str,
    ) -> Any:
        close_old_connections()
        result = await self.call(method, request_or_iterator, context)
        close_old_connections()
        return result
        



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: paperpilot_common/protobuf/test/test.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder

# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2

from paperpilot_common.protobuf.user import user_pb2 as paperpilot__common_dot_protobuf_dot_user_dot_user__pb2

DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(
    b'\n*paperpilot_common/protobuf/test/test.proto\x12\x04test\x1a\x1bgoogle/protobuf/empty.proto\x1a\x1fgoogle/protobuf/timestamp.proto\x1a*paperpilot_common/protobuf/user/user.proto"T\n\nTestResult\x12(\n\x04time\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x1c\n\x04user\x18\x02 \x01(\x0b\x32\x0e.user.UserInfo2E\n\x11TestPublicService\x12\x30\n\x04Test\x12\x16.google.protobuf.Empty\x1a\x10.test.TestResultb\x06proto3'
)

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, "paperpilot_common.protobuf.test.test_pb2", _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
    DESCRIPTOR._options = None
    _globals["_TESTRESULT"]._serialized_start = 158
    _globals["_TESTRESULT"]._serialized_end = 242
    _globals["_TESTPUBLICSERVICE"]._serialized_start = 244
    _globals["_TESTPUBLICSERVICE"]._serialized_end = 313
# @@protoc_insertion_point(module_scope)
